==> client-java-api-4.0.0-sources.jar: io/kubernetes/client/models/V1EnvFromSourceFluent.java <==
package io.kubernetes.client.models;

import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.Fluent;
import io.kubernetes.client.fluent.Nested;
import java.lang.String;
import java.lang.Deprecated;
import java.lang.Boolean;

public interface V1EnvFromSourceFluent<A extends V1EnvFromSourceFluent<A>> extends Fluent<A>{


    
/**
 * This method has been deprecated, please use method buildConfigMapRef instead.
 * @return The buildable object.
 */
@Deprecated public V1ConfigMapEnvSource getConfigMapRef();
    public V1ConfigMapEnvSource buildConfigMapRef();
    public A withConfigMapRef(V1ConfigMapEnvSource configMapRef);
    public Boolean hasConfigMapRef();
    public V1EnvFromSourceFluent.ConfigMapRefNested<A> withNewConfigMapRef();
    public V1EnvFromSourceFluent.ConfigMapRefNested<A> withNewConfigMapRefLike(V1ConfigMapEnvSource item);
    public V1EnvFromSourceFluent.ConfigMapRefNested<A> editConfigMapRef();
    public V1EnvFromSourceFluent.ConfigMapRefNested<A> editOrNewConfigMapRef();
    public V1EnvFromSourceFluent.ConfigMapRefNested<A> editOrNewConfigMapRefLike(V1ConfigMapEnvSource item);
    public String getPrefix();
    public A withPrefix(String prefix);
    public Boolean hasPrefix();
    
/**
 * This method has been deprecated, please use method buildSecretRef instead.
 * @return The buildable object.
 */
@Deprecated public V1SecretEnvSource getSecretRef();
    public V1SecretEnvSource buildSecretRef();
    public A withSecretRef(V1SecretEnvSource secretRef);
    public Boolean hasSecretRef();
    public V1EnvFromSourceFluent.SecretRefNested<A> withNewSecretRef();
    public V1EnvFromSourceFluent.SecretRefNested<A> withNewSecretRefLike(V1SecretEnvSource item);
    public V1EnvFromSourceFluent.SecretRefNested<A> editSecretRef();
    public V1EnvFromSourceFluent.SecretRefNested<A> editOrNewSecretRef();
    public V1EnvFromSourceFluent.SecretRefNested<A> editOrNewSecretRefLike(V1SecretEnvSource item);

    public interface ConfigMapRefNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1ConfigMapEnvSourceFluent<V1EnvFromSourceFluent.ConfigMapRefNested<N>>{

        
    public N and();    public N endConfigMapRef();
}
    public interface SecretRefNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1SecretEnvSourceFluent<V1EnvFromSourceFluent.SecretRefNested<N>>{

        
    public N and();    public N endSecretRef();
}


}

==> client-java-api-5.0.0-sources.jar: io/kubernetes/client/models/V1EnvFromSourceFluent.java <==
package io.kubernetes.client.models;

import java.lang.StringBuilder;
import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.Fluent;
import io.kubernetes.client.fluent.Nested;
import java.lang.String;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import java.lang.Boolean;

public interface V1EnvFromSourceFluent<A extends V1EnvFromSourceFluent<A>> extends Fluent<A>{


    
/**
 * This method has been deprecated, please use method buildConfigMapRef instead.
 * @return The buildable object.
 */
@Deprecated public V1ConfigMapEnvSource getConfigMapRef();
    public V1ConfigMapEnvSource buildConfigMapRef();
    public A withConfigMapRef(V1ConfigMapEnvSource configMapRef);
    public Boolean hasConfigMapRef();
    public V1EnvFromSourceFluent.ConfigMapRefNested<A> withNewConfigMapRef();
    public V1EnvFromSourceFluent.ConfigMapRefNested<A> withNewConfigMapRefLike(V1ConfigMapEnvSource item);
    public V1EnvFromSourceFluent.ConfigMapRefNested<A> editConfigMapRef();
    public V1EnvFromSourceFluent.ConfigMapRefNested<A> editOrNewConfigMapRef();
    public V1EnvFromSourceFluent.ConfigMapRefNested<A> editOrNewConfigMapRefLike(V1ConfigMapEnvSource item);
    public String getPrefix();
    public A withPrefix(String prefix);
    public Boolean hasPrefix();
    public A withNewPrefix(String arg1);
    public A withNewPrefix(StringBuilder arg1);
    public A withNewPrefix(StringBuffer arg1);
    
/**
 * This method has been deprecated, please use method buildSecretRef instead.
 * @return The buildable object.
 */
@Deprecated public V1SecretEnvSource getSecretRef();
    public V1SecretEnvSource buildSecretRef();
    public A withSecretRef(V1SecretEnvSource secretRef);
    public Boolean hasSecretRef();
    public V1EnvFromSourceFluent.SecretRefNested<A> withNewSecretRef();
    public V1EnvFromSourceFluent.SecretRefNested<A> withNewSecretRefLike(V1SecretEnvSource item);
    public V1EnvFromSourceFluent.SecretRefNested<A> editSecretRef();
    public V1EnvFromSourceFluent.SecretRefNested<A> editOrNewSecretRef();
    public V1EnvFromSourceFluent.SecretRefNested<A> editOrNewSecretRefLike(V1SecretEnvSource item);

    public interface ConfigMapRefNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1ConfigMapEnvSourceFluent<V1EnvFromSourceFluent.ConfigMapRefNested<N>>{

        
    public N and();    public N endConfigMapRef();
}
    public interface SecretRefNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1SecretEnvSourceFluent<V1EnvFromSourceFluent.SecretRefNested<N>>{

        
    public N and();    public N endSecretRef();
}


}
